@@ -1,9 +1,6 @@
 use strict;
 use warnings;
 
-# this does a conditional load of log4perl and if not found, stubs out
-# the logger calls. it should be called with a 'do' so that the code
-# executes in the caller's package.
 BEGIN {
   if ($INC{'Log/Log4perl.pm'}) {
     eval "use Log::Log4perl qw(:easy)";
@@ -18,3 +15,17 @@ BEGIN {
   my $glob = __PACKAGE__ . "::LOGDIE";
   *{$glob} = sub { die @_; } if !defined &$glob;
 };
+
+__END__
+
+=head1 NAME
+
+Google::RestApi logger_init.pl - Conditionally initialize log4perl.
+
+=head1 DESCRIPTION
+
+This does a conditional load of log4perl and if not found, stubs out
+the logger calls. it should be called with a 'do' so that the code
+executes in the caller's package.
+
+This should allow you to run the API with or without log4perl installed.
