@@ -10,7 +10,7 @@ sub new {
   my $self = RestApi->new(
     client_id     => 'mocked_client_id',
     client_secret => 'mocked_client_secret',
-    refresh_token => 'mocked_refresh_token',
+    token_file    => $0,
   );
   $self = Test::MockObject::Extends->new($self);
   $self->mock('token', sub { 'mocked_token'; });
